__author__ = "Marie Dumaz,Aldo Romero"
__copyright__ = "Copyright 2020"
__version__ = "1.0.1"
__email__ = (
    "mcd0029@mix.wvu.edu/alromero@mail.wvu.edu"
)
__status__ = "Development"
__date__ = "July 29th, 2020"

from .bibliometrics import Bibliometrics
